"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const grpc = __importStar(require("grpc"));
const protoLoader = __importStar(require("@grpc/proto-loader"));
const path = __importStar(require("path"));
function createClient(serviceName, filePath, endpoint) {
    const packageDefinition = protoLoader.loadSync(filePath, {
        includeDirs: [
            path.join(__dirname, '../')
        ],
    });
    const packageObject = grpc.loadPackageDefinition(packageDefinition);
    const clientConstructor = packageObject.mesg['api'][serviceName];
    return new clientConstructor(endpoint, grpc.credentials.createInsecure());
}
exports.createClient = createClient;
const statusKey = 'status';
const statusReady = 'ready';
const errNoStatus = new Error('stream header does not contain any status');
exports.errNoStatus = errNoStatus;
// checkStreamReady checks if MESG's gRPC stream is ready to serve data.
// if not, it returns a non-empty error.
const checkStreamReady = (metadata) => {
    const statuses = metadata.get(statusKey);
    if (!statuses.length) {
        return errNoStatus;
    }
    const lastStatus = statuses[statuses.length - 1];
    if (lastStatus != statusReady) {
        return new Error(`stream header status is different than ready. Got ${lastStatus}`);
    }
};
exports.checkStreamReady = checkStreamReady;
const promisify = (client, method) => (request) => {
    return new Promise((resolve, reject) => client[method](request, (err, res) => err ? reject(err) : resolve(res)));
};
exports.promisify = promisify;
